@@ -1,5 +1,5 @@
 /*  This file is part of "reprepro"
- *  Copyright (C) 2003,2004,2005,2006,2007,2009 Bernhard R. Link
+ *  Copyright (C) 2003,2004,2005,2006,2007,2009,2012 Bernhard R. Link
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
  *  published by the Free Software Foundation.
@@ -555,10 +555,9 @@ static retvalue changes_fixfields(const struct distribution *distribution, const
 			if (FAILEDTOALLOC(e->section))
 				return RET_ERROR_OOM;
 		}
-		if (strcmp(e->section, "unknown") == 0) {
-			fprintf(stderr, "Invalid section '%s' of '%s'!\n",
-					e->section, filename);
-			return RET_ERROR;
+		if (strcmp(e->section, "unknown") == 0 && verbose >= 0) {
+			fprintf(stderr, "Warning: '%s' contains strange section '%s'!\n",
+					filename, e->section);
 		}
 		if (strcmp(e->section, "-") == 0) {
 			fprintf(stderr,
