@@ -99,7 +99,7 @@ static inline retvalue filterlistfile_parse(struct filterlistfile *n, const char
 		lineno++;
 		lineend = strchr(line, '\n');
 		if (lineend == NULL) {
-			fprintf(stderr, "Overlong line in '%s'!\n", filename);
+			fprintf(stderr, "Overlong or unterminated line in '%s'!\n", filename);
 			return RET_ERROR;
 		}
 		while (lineend >= line && xisspace(*lineend))
