@@ -32,20 +32,20 @@
 #include "pool.h"
 #include "reference.h"
 
-retvalue references_isused(struct database *database,const char *what) {
-	return table_gettemprecord(database->references, what, NULL, NULL);
+retvalue references_isused( const char *what) {
+	return table_gettemprecord(rdb_references, what, NULL, NULL);
 }
 
-retvalue references_check(struct database *database,const char *referee,const struct strlist *filekeys) {
+retvalue references_check(const char *referee, const struct strlist *filekeys) {
 	int i;
 	retvalue result, r;
 
 	result = RET_NOTHING;
-	for( i = 0 ; i < filekeys->count ; i++ ) {
-		r = table_checkrecord(database->references,
+	for (i = 0 ; i < filekeys->count ; i++) {
+		r = table_checkrecord(rdb_references,
 				filekeys->values[i], referee);
-		if( r == RET_NOTHING ) {
-			fprintf(stderr,"Missing reference to '%s' by '%s'\n",
+		if (r == RET_NOTHING) {
+			fprintf(stderr, "Missing reference to '%s' by '%s'\n",
 					filekeys->values[i], referee);
 			r = RET_ERROR;
 		}
@@ -55,33 +55,33 @@ retvalue references_check(struct database *database,const char *referee,const st
 }
 
 /* add an reference to a file for an identifier. multiple calls */
-retvalue references_increment(struct database *database,const char *needed,const char *neededby) {
+retvalue references_increment(const char *needed, const char *neededby) {
 	retvalue r;
 
-	r = table_addrecord(database->references, needed,
+	r = table_addrecord(rdb_references, needed,
 			neededby, strlen(neededby), false);
-	if( RET_IS_OK(r) && verbose > 8 )
-		printf("Adding reference to '%s' by '%s'\n", needed,neededby);
+	if (RET_IS_OK(r) && verbose > 8)
+		printf("Adding reference to '%s' by '%s'\n", needed, neededby);
 	return r;
 }
 
 /* remove reference for a file from a given reference */
-retvalue references_decrement(struct database *database,const char *needed,const char *neededby) {
+retvalue references_decrement(const char *needed, const char *neededby) {
 	retvalue r;
 
-	r = table_removerecord(database->references, needed, neededby);
-	if( r == RET_NOTHING )
+	r = table_removerecord(rdb_references, needed, neededby);
+	if (r == RET_NOTHING)
 		return r;
-	if( RET_WAS_ERROR(r) ) {
+	if (RET_WAS_ERROR(r)) {
 		fprintf(stderr,
 "Error while trying to removing reference to '%s' by '%s'\n",
 				needed, neededby);
 		return r;
 	}
-	if( verbose > 8 )
-		fprintf(stderr,"Removed reference to '%s' by '%s'\n",
+	if (verbose > 8)
+		fprintf(stderr, "Removed reference to '%s' by '%s'\n",
 				needed, neededby);
-	if( RET_IS_OK(r) ) {
+	if (RET_IS_OK(r)) {
 		retvalue r2;
 		r2 = pool_dereferenced(needed);
 		RET_UPDATE(r, r2);
@@ -91,34 +91,34 @@ retvalue references_decrement(struct database *database,const char *needed,const
 
 /* Add an reference by <identifer> for the given <files>,
  * excluding <exclude>, if it is nonNULL. */
-retvalue references_insert(struct database *database,const char *identifier,
-		const struct strlist *files,const struct strlist *exclude) {
-	retvalue result,r;
+retvalue references_insert(const char *identifier,
+		const struct strlist *files, const struct strlist *exclude) {
+	retvalue result, r;
 	int i;
 
 	result = RET_NOTHING;
 
-	for( i = 0 ; i < files->count ; i++ ) {
+	for (i = 0 ; i < files->count ; i++) {
 		const char *filename = files->values[i];
 
-		if( exclude == NULL || !strlist_in(exclude,filename) ) {
-			r = references_increment(database, filename, identifier);
-			RET_UPDATE(result,r);
+		if (exclude == NULL || !strlist_in(exclude, filename)) {
+			r = references_increment(filename, identifier);
+			RET_UPDATE(result, r);
 		}
 	}
 	return result;
 }
 
 /* add possible already existing references */
-retvalue references_add(struct database *database,const char *identifier,const struct strlist *files) {
+retvalue references_add(const char *identifier, const struct strlist *files) {
 	int i;
 	retvalue r;
 
-	for( i = 0 ; i < files->count ; i++ ) {
+	for (i = 0 ; i < files->count ; i++) {
 		const char *filekey = files->values[i];
-		r = table_addrecord(database->references, filekey,
+		r = table_addrecord(rdb_references, filekey,
 				identifier, strlen(identifier), true);
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			return r;
 	}
 	return RET_OK;
@@ -126,20 +126,20 @@ retvalue references_add(struct database *database,const char *identifier,const s
 
 /* Remove reference by <identifer> for the given <oldfiles>,
  * excluding <exclude>, if it is nonNULL. */
-retvalue references_delete(struct database *database, const char *identifier, struct strlist *files, const struct strlist *exclude) {
-	retvalue result,r;
+retvalue references_delete(const char *identifier, struct strlist *files, const struct strlist *exclude) {
+	retvalue result, r;
 	int i;
 
-	assert( files != NULL );
+	assert (files != NULL);
 
 	result = RET_NOTHING;
 
-	for( i = 0 ; i < files->count ; i++ ) {
+	for (i = 0 ; i < files->count ; i++) {
 		const char *filekey = files->values[i];
 
-		if( exclude == NULL || !strlist_in(exclude,filekey) ) {
-			r = references_decrement(database, filekey, identifier);
-			RET_UPDATE(result,r);
+		if (exclude == NULL || !strlist_in(exclude, filekey)) {
+			r = references_decrement(filekey, identifier);
+			RET_UPDATE(result, r);
 		}
 	}
 	return result;
@@ -147,38 +147,68 @@ retvalue references_delete(struct database *database, const char *identifier, st
 }
 
 /* remove all references from a given identifier */
-retvalue references_remove(struct database *database, const char *neededby) {
+retvalue references_remove(const char *neededby) {
 	struct cursor *cursor;
 	retvalue result, r;
 	const char *found_to, *found_by;
 	size_t datalen, l;
 
-	r = table_newglobalcursor(database->references, &cursor);
-	if( !RET_IS_OK(r) )
+	r = table_newglobalcursor(rdb_references, &cursor);
+	if (!RET_IS_OK(r))
 		return r;
 
 	l = strlen(neededby);
 
 	result = RET_NOTHING;
-	while( cursor_nexttempdata(database->references, cursor,
-				&found_to, &found_by, &datalen) ) {
+	while (cursor_nexttempdata(rdb_references, cursor,
+				&found_to, &found_by, &datalen)) {
 
-		if( datalen >= l && strncmp(found_by, neededby, l) == 0 &&
+		if (datalen >= l && strncmp(found_by, neededby, l) == 0 &&
 		    (found_by[l] == '\0' || found_by[l] == ' ')) {
-			if( verbose > 8 )
-				fprintf(stderr,"Removing reference to '%s' by '%s'\n",
-					found_to,neededby);
-			r = cursor_delete(database->references, cursor,
+			if (verbose > 8)
+				fprintf(stderr,
+"Removing reference to '%s' by '%s'\n",
+					found_to, neededby);
+			r = cursor_delete(rdb_references, cursor,
 					found_to, NULL);
 			RET_UPDATE(result, r);
-			if( RET_IS_OK(r) ) {
+			if (RET_IS_OK(r)) {
 				r = pool_dereferenced(found_to);
 				RET_ENDUPDATE(result, r);
 			}
 		}
 	}
-	r = cursor_close(database->references, cursor);
+	r = cursor_close(rdb_references, cursor);
 	RET_ENDUPDATE(result, r);
 	return result;
 }
 
+/* dump all references to stdout */
+retvalue references_dump(void) {
+	struct cursor *cursor;
+	retvalue result, r;
+	const char *found_to, *found_by;
+
+	r = table_newglobalcursor(rdb_references, &cursor);
+	if (!RET_IS_OK(r))
+		return r;
+
+	result = RET_OK;
+	while (cursor_nexttemp(rdb_references, cursor,
+	                               &found_to, &found_by)) {
+		if (fputs(found_by, stdout) == EOF ||
+		    putchar(' ') == EOF ||
+		    puts(found_to) == EOF) {
+			result = RET_ERROR;
+			break;
+		}
+		result = RET_OK;
+		if (interrupted()) {
+			result = RET_ERROR_INTERRUPTED;
+			break;
+		}
+	}
+	r = cursor_close(rdb_references, cursor);
+	RET_ENDUPDATE(result, r);
+	return result;
+}
