@@ -1,5 +1,5 @@
 /*  This file is part of "reprepro"
- *  Copyright (C) 2008,2009 Bernhard R. Link
+ *  Copyright (C) 2003,2004,2005,2007,2008,2009,2012 Bernhard R. Link
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
  *  published by the Free Software Foundation.
@@ -32,15 +32,34 @@
 #include "checksums.h"
 #include "mprintf.h"
 #include "dirs.h"
+#include "chunks.h"
 #include "names.h"
 #include "aptmethod.h"
 #include "signature.h"
-#include "readrelease.h"
+#include "readtextfile.h"
 #include "uncompression.h"
 #include "diffindex.h"
 #include "rredpatch.h"
 #include "remoterepository.h"
 
+/*  This file is part of "reprepro"
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1301  USA
+ */
+#include <config.h>
+
+
+
 /* This is code to handle lists from remote repositories.
    Those are stored in the lists/ (or --listdir) directory
    and needs some maintaince:
@@ -97,15 +116,20 @@ struct remote_distribution {
 	/* linked list of key descriptions to check against, each must match */
 	struct signature_requirement *verify;
 
-	/* local copy of Release and Release.gpg file, once and if available */
+	/* local copy of InRelease, Release and Release.gpg file, once and if available */
+	char *inreleasefile;
 	char *releasefile;
 	char *releasegpgfile;
+	const char *usedreleasefile;
 
 	/* filenames and checksums from the Release file */
 	struct checksumsarray remotefiles;
 
 	/* the index files we need */
 	struct remote_index *indices;
+
+	/* InRelease failed or requested not to be used */
+	bool noinrelease;
 };
 
 struct remote_index {
@@ -178,6 +202,7 @@ static void remote_distribution_free(/*@only@*/struct remote_distribution *d) {
 		return;
 	free(d->suite);
 	signature_requirements_free(d->verify);
+	free(d->inreleasefile);
 	free(d->releasefile);
 	free(d->releasegpgfile);
 	free(d->suite_base_dir);
@@ -494,7 +519,7 @@ void cachedlistfile_need(struct cachedlistfile *list, const char *type, unsigned
 	}
 }
 
-retvalue remote_distribution_prepare(struct remote_repository *repository, const char *suite, bool ignorerelease, const char *verifyrelease, bool flat, bool *ignorehashes, struct remote_distribution **out_p) {
+retvalue remote_distribution_prepare(struct remote_repository *repository, const char *suite, bool ignorerelease, bool getinrelease, const char *verifyrelease, bool flat, bool *ignorehashes, struct remote_distribution **out_p) {
 	struct remote_distribution *n, **last;
 	enum checksumtype cs;
 
@@ -534,6 +559,15 @@ retvalue remote_distribution_prepare(struct remote_repository *repository, const
 						suite, repository->name);
 			n->ignorerelease = false;
 		}
+		if ((n->noinrelease && getinrelease) ||
+		    (!n->noinrelease && !getinrelease)) {
+			if (verbose >= 0)
+				fprintf(stderr,
+"Warning: Conflicting GetInRelease values for Suite '%s'\n"
+"from remote repository '%s'. Resolving to get InRelease files!\n",
+						suite, repository->name);
+			n->noinrelease = false;
+		}
 		for (cs = cs_md5sum ; cs < cs_hashCOUNT ; cs++) {
 			if ((n->ignorehashes[cs] && !ignorehashes[cs]) ||
 			    (!n->ignorehashes[cs] && ignorehashes[cs])) {
@@ -565,6 +599,7 @@ retvalue remote_distribution_prepare(struct remote_repository *repository, const
 	n->repository = repository;
 	n->suite = strdup(suite);
 	n->ignorerelease = ignorerelease;
+	n->noinrelease = !getinrelease;
 	if (verifyrelease != NULL) {
 		retvalue r;
 
@@ -586,6 +621,17 @@ retvalue remote_distribution_prepare(struct remote_repository *repository, const
 		return RET_ERROR_OOM;
 	}
 	/* ignorerelease can be unset later, so always calculate the filename */
+	if (flat)
+		n->inreleasefile = genlistsfilename("InRelease", 3,
+				repository->name, suite, "flat",
+				ENDOFARGUMENTS);
+	else
+		n->inreleasefile = genlistsfilename("InRelease", 2,
+				repository->name, suite, ENDOFARGUMENTS);
+	if (FAILEDTOALLOC(n->inreleasefile)) {
+		remote_distribution_free(n);
+		return RET_ERROR_OOM;
+	}
 	if (flat)
 		n->releasefile = genlistsfilename("Release", 3,
 				repository->name, suite, "flat",
@@ -641,12 +687,23 @@ static retvalue copytoplace(const char *gotfilename, const char *wantedfilename,
 	return RET_OK;
 }
 
+static retvalue enqueue_old_release_files(struct remote_distribution *d);
+
 /* handle a downloaded Release or Release.gpg file:
  * no checksums to test, nothing to trigger, as they have to be all
  * read at once to decide what is new and what actually needs downloading */
-static retvalue release_callback(enum queue_action action, UNUSED(void *privdata), UNUSED(void *privdata2), UNUSED(const char *uri), const char *gotfilename, const char *wantedfilename, UNUSED(/*@null@*/const struct checksums *checksums), const char *methodname) {
+static retvalue release_callback(enum queue_action action, void *privdata, void *privdata2, UNUSED(const char *uri), const char *gotfilename, const char *wantedfilename, UNUSED(/*@null@*/const struct checksums *checksums), const char *methodname) {
+	struct remote_distribution *d = privdata;
 	retvalue r;
 
+	/* if the InRelease file cannot be got,
+	 * try Release (and Release.gpg if checking) instead */
+	if (action == qa_error && privdata2 == d->inreleasefile) {
+		assert (!d->noinrelease);
+
+		return enqueue_old_release_files(d);
+	}
+
 	if (action != qa_got)
 		return RET_ERROR;
 
@@ -656,33 +713,47 @@ static retvalue release_callback(enum queue_action action, UNUSED(void *privdata
 	return r;
 }
 
+static retvalue enqueue_old_release_files(struct remote_distribution *d) {
+	retvalue r;
+
+	d->noinrelease = true;
+	r = aptmethod_enqueueindex(d->repository->download,
+			d->suite_base_dir, "Release", "",
+			d->releasefile, "",
+			release_callback, d, NULL);
+	if (RET_WAS_ERROR(r))
+		return r;
+	if (d->verify != NULL) {
+		r = aptmethod_enqueueindex(d->repository->download,
+				d->suite_base_dir, "Release", ".gpg",
+				d->releasegpgfile, "",
+				release_callback, d, NULL);
+		if (RET_WAS_ERROR(r))
+			return r;
+	}
+	return RET_OK;
+}
+
 static retvalue remote_distribution_metalistqueue(struct remote_distribution *d) {
 	struct remote_repository *repository = d->repository;
-	retvalue r;
 
 	assert (repository->download != NULL);
 
 	if (d->ignorerelease)
 		return RET_NOTHING;
 
+	(void)unlink(d->inreleasefile);
 	(void)unlink(d->releasefile);
-
-	r = aptmethod_enqueueindex(repository->download,
-			d->suite_base_dir, "Release", "", d->releasefile, "",
-			release_callback, NULL, NULL);
-	if (RET_WAS_ERROR(r))
-		return r;
-
 	if (d->verify != NULL) {
 		(void)unlink(d->releasegpgfile);
-		r = aptmethod_enqueueindex(repository->download,
-				d->suite_base_dir, "Release", ".gpg",
-				d->releasegpgfile, "",
-				release_callback, NULL, NULL);
-		if (RET_WAS_ERROR(r))
-			return r;
 	}
-	return RET_OK;
+
+	if (d->noinrelease)
+		return enqueue_old_release_files(d);
+	else
+		return aptmethod_enqueueindex(repository->download,
+			d->suite_base_dir, "InRelease", "", d->inreleasefile, "",
+			release_callback, d, d->inreleasefile);
 }
 
 retvalue remote_startup(struct aptmethodrun *run) {
@@ -737,15 +808,55 @@ static void find_index(const struct strlist *files, struct remote_index *ri) {
 	}
 }
 
+/* get a strlist with the md5sums of a Release-file */
+static inline retvalue release_getchecksums(const char *releasefile, const char *chunk, const bool ignorehash[cs_hashCOUNT], struct checksumsarray *out) {
+	retvalue r;
+	struct strlist files[cs_hashCOUNT];
+	enum checksumtype cs;
+	bool foundanything = false;
+
+	for (cs = cs_md5sum ; cs < cs_hashCOUNT ; cs++) {
+		if (ignorehash[cs]) {
+			strlist_init(&files[cs]);
+			continue;
+		}
+		assert (release_checksum_names[cs] != NULL);
+		r = chunk_getextralinelist(chunk, release_checksum_names[cs],
+				&files[cs]);
+		if (RET_WAS_ERROR(r)) {
+			while (cs-- > cs_md5sum) {
+				strlist_done(&files[cs]);
+			}
+			return r;
+		} else if (r == RET_NOTHING)
+			strlist_init(&files[cs]);
+		else
+			foundanything = true;
+	}
+
+	if (!foundanything) {
+		fprintf(stderr, "Missing checksums in Release file '%s'!\n",
+				releasefile);
+		return RET_ERROR;
+	}
+
+	r = checksumsarray_parse(out, files, releasefile);
+	for (cs = cs_md5sum ; cs < cs_hashCOUNT ; cs++) {
+		strlist_done(&files[cs]);
+	}
+	return r;
+}
+
 static retvalue process_remoterelease(struct remote_distribution *rd) {
 	struct remote_repository *rr = rd->repository;
 	struct remote_index *ri;
 	retvalue r;
+	char *releasedata;
+	size_t releaselen;
 
-	if (rd->verify != NULL) {
-		r = signature_check(rd->verify,
-				rd->releasegpgfile,
-				rd->releasefile);
+	if (!rd->noinrelease) {
+		r = signature_check_inline(rd->verify,
+				rd->inreleasefile, &releasedata);
 		assert (r != RET_NOTHING);
 		if (r == RET_NOTHING)
 			r = RET_ERROR_BADSIG;
@@ -757,9 +868,37 @@ static retvalue process_remoterelease(struct remote_distribution *rd) {
 		}
 		if (RET_WAS_ERROR(r))
 			return r;
+		rd->usedreleasefile = rd->inreleasefile;
+	} else {
+		r = readtextfile(rd->releasefile, rd->releasefile,
+				&releasedata, &releaselen);
+		assert (r != RET_NOTHING);
+		if (RET_WAS_ERROR(r))
+			return r;
+		rd->usedreleasefile = rd->releasefile;
+
+		if (rd->verify != NULL) {
+			r = signature_check(rd->verify,
+					rd->releasegpgfile, rd->releasefile,
+					releasedata, releaselen);
+			assert (r != RET_NOTHING);
+			if (r == RET_NOTHING)
+				r = RET_ERROR_BADSIG;
+			if (r == RET_ERROR_BADSIG) {
+				fprintf(stderr,
+"Error: Not enough signatures found for remote repository %s (%s %s)!\n",
+					rr->name, rr->method, rd->suite);
+				r = RET_ERROR_BADSIG;
+			}
+			if (RET_WAS_ERROR(r)) {
+				free(releasedata);
+				return r;
+			}
+		}
 	}
-	r = release_getchecksums(rd->releasefile, rd->ignorehashes,
-			&rd->remotefiles);
+	r = release_getchecksums(rd->usedreleasefile, releasedata,
+			rd->ignorehashes, &rd->remotefiles);
+	free(releasedata);
 	if (RET_WAS_ERROR(r))
 		return r;
 
@@ -792,6 +931,9 @@ retvalue remote_preparemetalists(struct aptmethodrun *run, bool nodownload) {
 	for (rr = repositories ; rr != NULL ; rr = rr->next) {
 		for (rd = rr->distributions ; rd != NULL ; rd = rd->next) {
 			if (!rd->ignorerelease) {
+				if (nodownload)
+					if (!isregularfile(rd->inreleasefile))
+						rd->noinrelease = true;
 				r = process_remoterelease(rd);
 				if (RET_WAS_ERROR(r))
 					return r;
@@ -1204,7 +1346,7 @@ static inline retvalue queueindex(struct remote_distribution *rd, struct remote_
 "but after unpacking '%s' looks wrong.\n"
 "Something is seriously broken!\n",
 							old[c]->fullfilename,
-							rd->releasefile,
+							rd->usedreleasefile,
 							ri->cachefilename);
 					}
 					if (r == RET_NOTHING) {
@@ -1251,7 +1393,7 @@ static retvalue queue_next_encoding(struct remote_distribution *rd, struct remot
 	if (rd->ignorerelease)
 		return queue_next_without_release(rd, ri);
 
-	r = find_requested_encoding(ri, rd->releasefile);
+	r = find_requested_encoding(ri, rd->usedreleasefile);
 	assert (r != RET_NOTHING);
 	if (RET_WAS_ERROR(r))
 		return r;
@@ -1959,7 +2101,7 @@ static retvalue diff_callback(enum queue_action action, void *privdata, UNUSED(v
 				ri->diffindex->destination, &dummy)) {
 			fprintf(stderr,
 "'%s' does not match file requested in '%s'. Aborting diff processing...\n",
-					gotfilename, rd->releasefile);
+					gotfilename, rd->usedreleasefile);
 			/* as this is claimed to be a common error
 			 * (outdated .diff/Index file), proceed with
 			 * other requested way to retrieve index file */
